@@ -6,7 +6,7 @@ import matplotlib.pyplot as plt
 des_center = (13.4349,-20.2091)
 hsc_center = (141.23246, 2.32358)
 des_mutli_center = (19.546018,  -28.189612)
-radius = 360*u.arcsec
+radius = 120*u.arcsec
 
 hsc_error_center = (33.15582, -1.5446)
 d = load_dataset("des")
@@ -14,10 +14,16 @@ d = load_dataset("des")
 
 
 a = d.cone_search(des_center, radius, dtypes=["catalog", "mask"])
-print(a)
+c = a["catalog"]
+m = a["mask"]
+print(c)
+print(c[m])
 
 d = load_dataset("hsc")
 
 
 a = d.cone_search(hsc_center, radius, dtypes=["catalog", "mask"])
-print(a)
+c = a["catalog"]
+m = a["mask"]
+print(c)
+print(c[m])
